@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "biblio" "0.3"
-  "Browse and import bibliographic references from CrossRef, arXiv, DBLP, HAL, Dissemin, and doi.org."
+(define-package "biblio" "20250812.1408"
+  "Browse and import bibliographic references and BibTeX records from CrossRef, arXiv, DBLP, HAL, IEEE Xplore, Dissemin, and doi.org."
   '((emacs       "24.3")
-    (biblio-core "0.2"))
+    (biblio-core "0.3"))
   :url "https://github.com/cpitclaudel/biblio.el"
-  :commit "ee52f6cda82ea6fbc3b400e7b12132595cc0374c"
-  :revdesc "0.3-0-gee52f6cda82e"
+  :commit "bb9d6b4b962fb2a4e965d27888268b66d868766b"
+  :revdesc "bb9d6b4b962f"
   :keywords '("bib" "tex" "convenience" "hypermedia")
   :authors '(("Clément Pit-Claudel" . "clement.pitclaudel@live.com"))
   :maintainers '(("Clément Pit-Claudel" . "clement.pitclaudel@live.com")))
